==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/ListAction.hpp <==
#ifndef _COM_SUN_STAR_UCB_LISTACTION_HPP_
#define _COM_SUN_STAR_UCB_LISTACTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_LISTACTION_HDL_
#include "com/sun/star/ucb/ListAction.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline ListAction::ListAction() SAL_THROW( () )
    : Position(0)
    , Count(0)
    , ListActionType(0)
    , ActionInfo()
{
}

inline ListAction::ListAction(const ::sal_Int32& Position_, const ::sal_Int32& Count_, const ::sal_Int32& ListActionType_, const ::com::sun::star::uno::Any& ActionInfo_) SAL_THROW( () )
    : Position(Position_)
    , Count(Count_)
    , ListActionType(ListActionType_)
    , ActionInfo(ActionInfo_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::ListAction const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.ucb.ListAction");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_UCB_LISTACTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/ListAction.hpp <==
#ifndef _COM_SUN_STAR_UCB_LISTACTION_HPP_
#define _COM_SUN_STAR_UCB_LISTACTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_LISTACTION_HDL_
#include "com/sun/star/ucb/ListAction.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline ListAction::ListAction() SAL_THROW( () )
    : Position(0)
    , Count(0)
    , ListActionType(0)
    , ActionInfo()
{
}

inline ListAction::ListAction(const ::sal_Int32& Position_, const ::sal_Int32& Count_, const ::sal_Int32& ListActionType_, const ::com::sun::star::uno::Any& ActionInfo_) SAL_THROW( () )
    : Position(Position_)
    , Count(Count_)
    , ListActionType(ListActionType_)
    , ActionInfo(ActionInfo_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::ListAction const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.ucb.ListAction");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::ListAction const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::ucb::ListAction >::get();
}

#endif // _COM_SUN_STAR_UCB_LISTACTION_HPP_
